tietools.TieChain
=================

.. abjad-lineage:: abjad.tools.tietools.TieChain.TieChain.TieChain

.. autoclass:: abjad.tools.tietools.TieChain.TieChain.TieChain
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.all_leaves_are_in_same_parent
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.head
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.is_pitched
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.is_trivial
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.leaves
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.leaves_grouped_by_immediate_parents
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.music
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.start_offset
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.timespan
   :noindex:

.. autoattribute:: abjad.tools.tietools.TieChain.TieChain.TieChain.written_duration
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__add__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__contains__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__eq__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__ge__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__getitem__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__gt__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__le__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__len__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__lt__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__ne__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__radd__
   :noindex:

.. automethod:: abjad.tools.tietools.TieChain.TieChain.TieChain.__repr__
   :noindex:
